@@ -34,10 +34,9 @@
 #' 
 #' @param ... Not used.
 #' 
-#' @param useNames If \code{\link[base]{NA}}, the default behavior of the 
-#' function about naming support is remained. If \code{\link[base:logical]{FALSE}}, 
-#' no naming support is done. Else if \code{\link[base:logical]{TRUE}}, names 
-#' attributes of result are set. 
+#' @param useNames If \code{\link[base:logical]{FALSE}} (default), no naming
+#' support is done. Else if \code{\link[base:logical]{TRUE}}, names attributes
+#' of result are set. 
 #'
 #' @return \code{rowAlls()} (\code{colAlls()}) returns an
 #' \code{\link[base]{logical}} \code{\link[base]{vector}} of length N (K).
@@ -56,8 +55,9 @@
 #' @keywords array logic iteration univar
 #' @export
 rowAlls <- function(x, rows = NULL, cols = NULL, value = TRUE,
-                    na.rm = FALSE, dim. = dim(x), ..., useNames = NA) {
+                    na.rm = FALSE, dim. = dim(x), ..., useNames = TRUE) {
   if (is.numeric(x) && is.logical(value) && !is.na(value)) {
+    if (is.na(useNames)) deprecatedUseNamesNA()
     has_nas <- TRUE
     if (isTRUE(value)) {
       counts <- .Call(C_rowCounts, x, dim., rows, cols, FALSE, 1L, na.rm, has_nas, useNames)
@@ -86,6 +86,8 @@ rowAlls <- function(x, rows = NULL, cols = NULL, value = TRUE,
       } else {
         names(res) <- NULL
       }
+    } else {
+      deprecatedUseNamesNA()
     }
   } else {
     if (!identical(dim(x), dim.)) dim(x) <- dim.
@@ -115,8 +117,9 @@ rowAlls <- function(x, rows = NULL, cols = NULL, value = TRUE,
 #' @rdname rowAlls
 #' @export
 colAlls <- function(x, rows = NULL, cols = NULL, value = TRUE,
-                    na.rm = FALSE, dim. = dim(x), ..., useNames = NA) {
+                    na.rm = FALSE, dim. = dim(x), ..., useNames = TRUE) {
   if (is.numeric(x) && is.logical(value) && !is.na(value)) {
+    if (is.na(useNames)) deprecatedUseNamesNA()
     has_nas <- TRUE
     if (isTRUE(value)) {
       counts <- .Call(C_colCounts, x, dim., rows, cols, FALSE, 1L, na.rm, has_nas, useNames)
@@ -203,8 +206,9 @@ allValue <- function(x, idxs = NULL, value = TRUE, na.rm = FALSE, ...) {
 #' @rdname rowAlls
 #' @export
 rowAnys <- function(x, rows = NULL, cols = NULL, value = TRUE,
-                    na.rm = FALSE, dim. = dim(x), ..., useNames = NA) {
+                    na.rm = FALSE, dim. = dim(x), ..., useNames = TRUE) {
   if (is.numeric(x) && is.logical(value) && !is.na(value)) {
+    if (is.na(useNames)) deprecatedUseNamesNA()
     has_nas <- TRUE
     if (isTRUE(value)) {
       counts <- .Call(C_rowCounts, x, dim., rows, cols, FALSE, 0L, na.rm, has_nas, useNames)
@@ -249,8 +253,9 @@ rowAnys <- function(x, rows = NULL, cols = NULL, value = TRUE,
 #' @rdname rowAlls
 #' @export
 colAnys <- function(x, rows = NULL, cols = NULL, value = TRUE,
-                    na.rm = FALSE, dim. = dim(x), ..., useNames = NA) {
+                    na.rm = FALSE, dim. = dim(x), ..., useNames = TRUE) {
   if (is.numeric(x) && is.logical(value) && !is.na(value)) {
+    if (is.na(useNames)) deprecatedUseNamesNA()
     has_nas <- TRUE
     if (isTRUE(value)) {
       counts <- .Call(C_colCounts, x, dim., rows, cols, FALSE, 0L, na.rm, has_nas, useNames)
