@@ -18,16 +18,17 @@ SEXP signTabulate(SEXP x, SEXP idxs) {
 
   /* Argument 'idxs': */
   R_xlen_t nidxs;
-  R_xlen_t *cidxs = validateIndices(idxs, nx, 1, &nidxs);
+  int idxsHasNA;
+  R_xlen_t *cidxs = validateIndicesCheckNA(idxs, nx, 1, &nidxs, &idxsHasNA);
 
   /* Double matrices are more common to use. */
   if (isReal(x)) {
     PROTECT(ans = allocVector(REALSXP, 6));
-    signTabulate_dbl(REAL(x), nx, cidxs, nidxs, REAL(ans));
+    signTabulate_dbl(REAL(x), nx, cidxs, nidxs, idxsHasNA, REAL(ans));
     UNPROTECT(1);
   } else if (isInteger(x)) {
     PROTECT(ans = allocVector(REALSXP, 4));
-    signTabulate_int(INTEGER(x), nx, cidxs, nidxs, REAL(ans));
+    signTabulate_int(INTEGER(x), nx, cidxs, nidxs, idxsHasNA, REAL(ans));
     UNPROTECT(1);
   }
 
