@@ -19,14 +19,14 @@ rowCumsums_R <- function(x, ..., useNames = NA) {
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 # With and without some NAs
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-dimnames = list(letters[1:20], LETTERS[1:5]) # to check dimnames attribute
+dimnames <- list(letters[1:10], LETTERS[1:5]) # to check dimnames attribute
 for (mode in c("logical", "integer", "double")) {
   for (add_na in c(FALSE, TRUE)) {
     cat("add_na = ", add_na, "\n", sep = "")
 
-    x <- matrix(1:100, nrow = 20, ncol = 5)
+    x <- matrix(1:50, nrow = 10L, ncol = 5L)
     if (add_na) {
-      x[13:17, c(2, 4)] <- NA_real_
+      x[3:7, c(2, 4)] <- NA_real_
     }
     cat("mode: ", mode, "\n", sep = "")
     storage.mode(x) <- mode
@@ -55,7 +55,7 @@ for (mode in c("logical", "integer", "double")) {
 # All NAs
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 for (mode in c("logical", "integer", "double")) {
-  x <- matrix(NA_real_, nrow = 20, ncol = 5)
+  x <- matrix(NA_real_, nrow = 10L, ncol = 5L)
   cat("mode: ", mode, "\n", sep = "")
   storage.mode(x) <- mode
   str(x)
@@ -81,9 +81,9 @@ for (mode in c("logical", "integer", "double")) {
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 # A 1x1 matrix
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-dimnames = list("a", "A") # to check dimnames attribute
+dimnames <- list("a", "A") # to check dimnames attribute
 for (mode in c("logical", "integer", "double")) {
-  x <- matrix(0, nrow = 1, ncol = 1)
+  x <- matrix(0, nrow = 1L, ncol = 1L)
   cat("mode: ", mode, "\n", sep = "")
   storage.mode(x) <- mode
   str(x)
